%define shortver 78

# %%{_bindir}/nviz is included in grass
%global __requires_exclude nviz

Name:		grass
Version:	7.8.3
Release:	%mkrel 5
Group:		Sciences/Geosciences
Summary:	Geographic Resources Analysis Support System
License:	GPLv2+
URL:		http://grass.osgeo.org/

Source0:	http://grass.osgeo.org/grass%{shortver}/source/grass-%{version}.tar.gz


BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(gdlib) >= 2.0
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	tk
BuildRequires:	pkgconfig(tk)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	gdbm-devel
BuildRequires:	pkgconfig(readline)
BuildRequires:	postgresql-devel
BuildRequires:	gcc-gfortran
BuildRequires:	pkgconfig(gdal)
BuildRequires:	flex
BuildRequires:	swig
BuildRequires:	bison
BuildRequires:	pkgconfig(proj)
BuildRequires:	proj >= 4.4.7
BuildRequires:	tcl
BuildRequires:	pkgconfig(tcl)
BuildRequires:  lapack-devel
BuildRequires:  blas-devel
BuildRequires:  libgomp-devel
BuildRequires:	pkgconfig(cfitsio)
BuildRequires:	pkgconfig(odbc)
BuildRequires:	mysql-devel
BuildRequires:	termcap-devel
#BuildRequires:	ffmpeg-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:  python3dist(wxpython)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	python3dist(numpy)
BuildRequires:	python3dist(six)
BuildRequires:  python3dist(python-dateutil)
BuildRequires:	imagemagick
BuildRequires:	lzma
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(OpenCL)

Requires:	xterm
Requires:	tk
Requires:	tcl
Requires:       python3-wxpython4


%description
GRASS (Geographic Resources Analysis Support System) is an
open source, Free Software Geographical Information System (GIS)
with raster, topological vector, image processing, and graphics
production functionality that operates on various platforms
through a graphical user interface and shell in X-Window.

%prep
%setup -q
%autopatch -p1


%build
%define Werror_cflags %nil

%configure --host=%{_host} \
%if "%_lib" != "lib"
	--enable-64bit \
%endif
	--with-dbm-includes=%{_includedir}/gdbm/ \
	--with-postgres \
	--with-postgres-includes=%{_includedir}/ \
	--with-freetype \
	--with-freetype-includes=%{_includedir}/freetype2 \
	--with-motif \
	--with-cairo \
        --with-openmp \
	--with-lapack \
        --with-lapack-libs=%{_libdir} \
        --with-blas \
	--with-blas-libs=%{_libdir} \
        --with-opengl-libs=%{_libdir} \
	--with-motif-libs=%{_libdir} \
	--with-motif-libs=%{_libdir} \
	--with-motif-includes=%{_includedir} \
	--with-gdal  \
        --with-geos \
	--with-mysql --with-mysql-includes=%{_includedir}/mysql \
	--with-odbc \
	--enable-largefile \
	--with-curses \
	--with-python --with-wxwidgets="%{_bindir}/wx-config"\
	--with-sqlite \
	--with-cxx \
	--with-proj-share=%{_datadir}/proj \
	--with-nls \
	--with-readline \
	--with-bzlib \
	--with-zstd \
        --with-opencl \
        --with-opencl-libs=%{_libdir} \
	--with-netcdf
#   --with-ffmpeg --with-ffmpeg-includes="%%{_includedir}/libavcodec \
#   %%{_includedir}/libavdevice \
#   %%{_includedir}/libavformat %%{_includedir}/libavutil \
#   %%{_includedir}/libpostproc %%{_includedir}/libswscale"

%make_build

%install
%__mkdir -p %{buildroot}%{_bindir}
%make_install INST_DIR=%{buildroot}%{_libdir}/grass%{shortver} UNIX_BIN=%{buildroot}%{_bindir}

# fix paths:
# Change GISBASE in startup script
for I in %{buildroot}%{_bindir}/%{name}%{shortver} \
	%{buildroot}%{_libdir}/%{name}%{shortver}/include/Make/Platform.make \
	%{buildroot}%{_libdir}/%{name}%{shortver}/include/Make/Grass.make \
	%{buildroot}%{_libdir}/%{name}%{shortver}/demolocation/.grassrc%{shortver} \
	%{buildroot}%{_libdir}/%{name}%{shortver}/etc/fontcap; do
	sed -i \
		-e 's|%{buildroot}%{_libdir}/%{name}-%{version}|%{_libdir}/%{name}%{shortver}|g' \
		-e 's|%{buildroot}%{_libdir}/%{name}%{shortver}|%{_libdir}/%{name}%{shortver}|g' \
		-e 's|%{buildroot}%{_bindir}|%{_bindir}|g' \
		$I
done

# fix paths in grass.pc
sed -i -e 's|%{_prefix}/%{name}-%{version}|%{_libdir}/%{name}%{shortver}|g' \
	%{name}.pc


sed -e 's|MGAGISBASE|"%{_libdir}/grass%{shortver}"|' \
 bin.%{_target_platform}/grass%{shortver} > %{buildroot}%{_bindir}/grass%{shortver}
chmod a+x %{buildroot}/usr/bin/grass%{shortver}

for i in {16,22,24,32,36,48,64,72,96,128,192}
do
  %__install -p -D dist.%{_target_platform}/gui/icons/%{name}-${i}x${i}.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png
done


%__mkdir %{buildroot}/%{_libdir}/grass%{shortver}/locks
%__chmod 1777 %{buildroot}/%{_libdir}/grass%{shortver}/locks



%__mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}.desktop << EOF
[Desktop Entry]
Name=Grass%{shortver}
Comment=Geographic Resources Analysis Support System
Exec=grass%{shortver}
Icon=%{name}
Terminal=true
Type=Application
Categories=Science;Geology;
EOF

%__mkdir -p %{buildroot}%_sysconfdir/ld.so.conf.d
cat > %{buildroot}%_sysconfdir/ld.so.conf.d/grass.conf << EOF
%{_libdir}/grass%{shortver}/lib
EOF



%files
%doc AUTHORS COPYING README.md CHANGES
%attr(0755,root,root) %{_bindir}/*
%{_sysconfdir}/ld.so.conf.d/*
%{_libdir}/grass%{shortver}/
%{_datadir}/applications/%{_real_vendor}-%{name}.desktop
%{_iconsdir}/*/*/*/*


%changelog
* Mon Oct 26 2020 akien <akien> 7.8.3-5.mga8
+ Revision: 1639629
- Rebuild against libnetcdf18

* Thu Oct 01 2020 pterjan <pterjan> 7.8.3-4.mga8
+ Revision: 1631514
- Rebuild for new netcdf on arm

* Thu Jul 16 2020 daviddavid <daviddavid> 7.8.3-3.mga8
+ Revision: 1606462
- rebuild for new gdal 3.1.2

* Sat Jun 27 2020 joequant <joequant> 7.8.3-2.mga8
+ Revision: 1599666
- bump version
- fix buildroot errors

* Wed May 06 2020 daviddavid <daviddavid> 7.8.3-1.mga8
+ Revision: 1580970
- new version: 7.8.3

* Sat Apr 18 2020 daviddavid <daviddavid> 7.8.2-3.mga8
+ Revision: 1568589
- rebuild for new proj 7.0.0
+ eatdirt <eatdirt>
- Switch to python3
- Upgrade to version 7.8.2, rebuild for new libproj

* Sun Mar 15 2020 daviddavid <daviddavid> 7.8.1-4.mga8
+ Revision: 1556459
- rebuild for new gdal 3.0.4

* Tue Feb 18 2020 umeabot <umeabot> 7.8.1-3.mga8
+ Revision: 1542170
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 7.8.1-2.mga8
+ Revision: 1475961
- rebuild for readline

* Sat Nov 09 2019 zezinho <zezinho> 7.8.1-1.mga8
+ Revision: 1458921
- new version 7.8.0

* Mon May 06 2019 daviddavid <daviddavid> 7.6.1-2.mga7
+ Revision: 1396575
- enable zstd and bzip2 support

* Wed Apr 17 2019 eatdirt <eatdirt> 7.6.1-1.mga7
+ Revision: 1392080
- Upgrade to version 7.6.1

* Mon Mar 11 2019 daviddavid <daviddavid> 7.6.0-4.mga7
+ Revision: 1374352
- switch to sqlite3

* Fri Mar 08 2019 eatdirt <eatdirt> 7.6.0-3.mga7
+ Revision: 1372790
- Fix build against new proj
- Rebuild for new proj

* Thu Mar 07 2019 eatdirt <eatdirt> 7.6.0-1.mga7
+ Revision: 1372173
- Upgrade to version 7.6.0

* Wed Jan 09 2019 eatdirt <eatdirt> 7.4.4-2.mga7
+ Revision: 1353638
- Fix hardcoded build directory in launcher

* Wed Jan 09 2019 eatdirt <eatdirt> 7.4.4-1.mga7
+ Revision: 1353488
- Upgrade to version 7.4.4

* Sun Sep 23 2018 umeabot <umeabot> 7.4.1-2.mga7
+ Revision: 1298070
- Mageia 7 Mass Rebuild

* Tue Jul 31 2018 eatdirt <eatdirt> 7.4.1-1.mga7
+ Revision: 1246400
- Upgrade to version 7.4.1

* Mon Jun 11 2018 daviddavid <daviddavid> 7.4.0-2.mga7
+ Revision: 1236276
- remove no more available BR lesstif-devel

* Mon Mar 19 2018 eatdirt <eatdirt> 7.4.0-1.mga7
+ Revision: 1210451
- Upgrade to version 7.4.0

* Sat Mar 17 2018 daviddavid <daviddavid> 7.2.2-3.mga7
+ Revision: 1210037
- rebuild for new proj 5.0.0

* Sat Dec 23 2017 wally <wally> 7.2.2-2.mga7
+ Revision: 1184224
- rebuild for new mariadb

* Tue Oct 31 2017 eatdirt <eatdirt> 7.2.2-1.mga7
+ Revision: 1175220
- Upgrade to version 7.2.2

* Wed Jun 22 2016 eatdirt <eatdirt> 7.0.4-3.mga6
+ Revision: 1037221
- Fix hardcoded build path in binaries

* Thu Jun 02 2016 daviddavid <daviddavid> 7.0.4-2.mga6
+ Revision: 1019840
- rebuild for wxgtk3.0 built with GTK2

* Fri May 20 2016 eatdirt <eatdirt> 7.0.4-1.mga6
+ Revision: 1017268
- Upgrade to version 7.0.4
- Upgrade to version 7.0.4

* Fri May 20 2016 tv <tv> 6.4.4-8.mga6
+ Revision: 1017106
- rebuild for new libproj

* Sun Jan 10 2016 wally <wally> 6.4.4-7.mga6
+ Revision: 920921
- rebuild for new gdal

* Mon Oct 05 2015 daviddavid <daviddavid> 6.4.4-6.mga6
+ Revision: 886351
- rebuild for new tcl/tk 8.6.4

* Tue Nov 25 2014 cjw <cjw> 6.4.4-5.mga5
+ Revision: 799065
- rebuild against postgresql9.4

* Sat Oct 18 2014 danf <danf> 6.4.4-4.mga5
+ Revision: 788262
- Added libgrass_rli.patch to fix bad package requires due to
  unversioned linking of libgrass_rli

* Wed Oct 15 2014 umeabot <umeabot> 6.4.4-3.mga5
+ Revision: 750182
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Sat Jul 05 2014 matteo <matteo> 6.4.4-1.mga5
+ Revision: 643832
- new stable version 6.4.4

* Sat Oct 19 2013 umeabot <umeabot> 6.4.3-2.mga4
+ Revision: 534269
- Mageia 4 Mass Rebuild

* Tue Sep 10 2013 fwang <fwang> 6.4.3-1.mga4
+ Revision: 477071
- fix convert
- disable ffmpeg as it still failed
- new version 6.4.3

* Mon Jun 03 2013 fwang <fwang> 6.4.2-6.mga4
+ Revision: 435944
- rebuild for new libpng
+ obgr_seneca <obgr_seneca>
- Rebuild for new geos

* Sat Jan 12 2013 umeabot <umeabot> 6.4.2-4.mga3
+ Revision: 352586
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Aug 26 2012 obgr_seneca <obgr_seneca> 6.4.2-3.mga3
+ Revision: 284165
- added patch for gcc 4.7
- Disabled ffmpeg support due to API changes in ffmpeg
- Can be reenabled when upstream fixes it
- Rebuild against libavcodec54
+ fwang <fwang>
- use autoreconf
- try to build with ffmpeg 0.11

* Wed Mar 07 2012 matteo <matteo> 6.4.2-1.mga2
+ Revision: 221324
- new version 6.4.2

* Mon Feb 13 2012 dmorgan <dmorgan> 6.4.1-12.mga2
+ Revision: 208362
- mesaglw-devel does not exist anymore, so remove from buildrequires

* Fri Dec 23 2011 fwang <fwang> 6.4.1-11.mga2
+ Revision: 186521
- rebuild for new libtiff

* Sat Dec 10 2011 eatdirt <eatdirt> 6.4.1-10.mga2
+ Revision: 180291
- Rebuilt for fftw-3.3

* Thu Dec 08 2011 fwang <fwang> 6.4.1-9.mga2
+ Revision: 178843
- rebuild for new odbc

* Thu Nov 03 2011 obgr_seneca <obgr_seneca> 6.4.1-8.mga2
+ Revision: 161927
- rebuild against new geos

* Tue Sep 27 2011 obgr_seneca <obgr_seneca> 6.4.1-7.mga2
+ Revision: 149568
- rebuild against new geos and changes in gdal

* Sat Sep 17 2011 matteo <matteo> 6.4.1-6.mga2
+ Revision: 144502
- added patch to support libpng15
+ fwang <fwang>
- wrong linkage for grass

* Fri Sep 16 2011 matteo <matteo> 6.4.1-5.mga2
+ Revision: 144291
- patch to let grass compile using libpng12 (atm grass do not compile with default libpng15)
+ fwang <fwang>
- rebuild for new libpng

* Mon Jul 11 2011 ahmad <ahmad> 6.4.1-4.mga2
+ Revision: 122159
- Add a _requires_exceptions for nviz, already included in grass

* Wed Jul 06 2011 fwang <fwang> 6.4.1-3.mga2
+ Revision: 119180
- rebuild for new tcl

* Tue Jun 28 2011 fwang <fwang> 6.4.1-2.mga2
+ Revision: 115123
- rebuild

* Fri Jun 24 2011 fwang <fwang> 6.4.1-1.mga2
+ Revision: 113060
- more ffmpeg 0.8 patch
- fix build with ffmpeg 0.8
- new version 6.4.1

* Tue Apr 26 2011 wally <wally> 6.4.0-9.mga1
+ Revision: 91669
- fix desktop file (mga#954)

* Wed Apr 20 2011 obgr_seneca <obgr_seneca> 6.4.0-8.mga1
+ Revision: 89183
- rebuild agains new libgdal-1.8.0

* Wed Mar 30 2011 ahmad <ahmad> 6.4.0-7.mga1
+ Revision: 79121
- modify wx-config path in the configure option
+ ennael <ennael>
- clean spec file
- imported package grass

